@@ -8,7 +8,7 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import TYPE_CHECKING, cast
 
-from aspy.refactor_imports.classify import ImportType, classify_import
+from classify_imports import Classified, classify_base
 
 from flake8_type_checking.constants import (
     ANNOTATION_PROPERTY,
@@ -52,7 +52,6 @@ class AttrsMixin:
         attrs_imports: dict[Optional[str], str] = {}  # map of alias to full import name
 
         for node in self.third_party_imports.values():
-
             module = getattr(node, 'module', '')
             names: list[Name] = getattr(node, 'names', [])
 
@@ -332,7 +331,7 @@ class ImportName:
     @property
     def import_type(self) -> ImportTypeValue:
         """Return the import type of the import."""
-        return cast(ImportTypeValue, classify_import(self.full_name))
+        return cast(ImportTypeValue, classify_base(self.full_name.partition('.')[0]))
 
 
 class ImportVisitor(DunderAllMixin, AttrsMixin, FastAPIMixin, PydanticMixin, ast.NodeVisitor):
@@ -514,7 +513,6 @@ class ImportVisitor(DunderAllMixin, AttrsMixin, FastAPIMixin, PydanticMixin, ast
             return
 
         for name_node in node.names:
-
             # Skip checking the import if the module is passlisted
             if isinstance(node, ast.Import) and name_node.name in self.exempt_modules:
                 return
@@ -545,18 +543,17 @@ class ImportVisitor(DunderAllMixin, AttrsMixin, FastAPIMixin, PydanticMixin, ast
 
             # Classify and map imports
             if name_node.name not in self.exempt_imports:
-
                 imp = ImportName(
                     _module=f'{node.module}.' if isinstance(node, ast.ImportFrom) else '',
                     _alias=name_node.asname,
                     _name=name_node.name,
                 )
 
-                if imp.import_type == ImportType.APPLICATION:
+                if imp.import_type == Classified.APPLICATION:
                     self.application_imports[imp.import_name] = node
-                elif imp.import_type == ImportType.THIRD_PARTY:
+                elif imp.import_type == Classified.THIRD_PARTY:
                     self.third_party_imports[imp.import_name] = node
-                elif imp.import_type == ImportType.BUILTIN:
+                elif imp.import_type == Classified.BUILTIN:
                     self.built_in_imports[imp.import_name] = node
                 else:
                     """
@@ -565,7 +562,7 @@ class ImportVisitor(DunderAllMixin, AttrsMixin, FastAPIMixin, PydanticMixin, ast
                     We need to know if this is present or not, to determine whether
                     or not PEP563 is enabled: https://peps.python.org/pep-0563/
                     """
-                    if self.futures_annotation is None and imp.import_type == ImportType.FUTURE:
+                    if self.futures_annotation is None and imp.import_type == Classified.FUTURE:
                         if any(name.name == 'annotations' for name in node.names):
                             self.futures_annotation = True
                             return
@@ -830,9 +827,9 @@ class TypingOnlyImportsChecker:
     def unused_imports(self) -> Flake8Generator:
         """Yield TC001, TC002, and TC003 errors."""
         import_types = {
-            ImportType.APPLICATION: (self.visitor.application_imports, TC001),
-            ImportType.THIRD_PARTY: (self.visitor.third_party_imports, TC002),
-            ImportType.BUILTIN: (self.visitor.built_in_imports, TC003),
+            Classified.APPLICATION: (self.visitor.application_imports, TC001),
+            Classified.THIRD_PARTY: (self.visitor.third_party_imports, TC002),
+            Classified.BUILTIN: (self.visitor.built_in_imports, TC003),
         }
 
         unused_imports = set(self.visitor.imports) - self.visitor.names
